@@ -1,10 +1,39 @@
+#!/usr/bin/env perl
 #
-# Copyright (C) 2004 David J. Goehrig
+# SDL.pm
+#
+# Copyright (C) 2005 David J. Goehrig <dgoehrig@cpan.org>
+#
+# ------------------------------------------------------------------------------
+#
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+# 
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+# 
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#
+# ------------------------------------------------------------------------------
+#
+# Please feel free to send questions, suggestions or improvements to:
+#
+#	David J. Goehrig
+#	dgoehrig@cpan.org
 #
 
 package SDL;
 
 use strict;
+use warnings;
+use Carp;
+
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
 require Exporter;
@@ -16,14 +45,17 @@ use SDL::Constants;
 BEGIN {
 	@ISA = qw(Exporter DynaLoader);
 	@EXPORT = qw( in verify &NULL );
-	# reexport all SDL constants
-	for (@SDL::Constants::EXPORT) {
-		push @EXPORT,$_;
-	}
 };
 
+# Give our caller SDL::Constant's stuff as well as ours.
+sub import {
+  my $self = shift;
 
-$VERSION = '2.1.2';
+  $self->export_to_level(1, @_);
+  SDL::Constants->export_to_level(1);
+}
+
+$VERSION = '2.2.1';
 
 print "$VERSION" if (defined($ARGV[0]) && ($ARGV[0] eq '--SDLperl'));
 
@@ -35,13 +67,17 @@ sub NULL {
 
 sub in {
 	my ($k,@t) = @_;
-	(scalar grep { defined $_ && $_ eq $k } @t) <=> 0;
+	return 0 unless defined $k;
+	my $r = ((scalar grep { defined $_ && $_ eq $k } @t) <=> 0);
+	return 0 if $r eq '';
+	return $r;
+
 } 
 
 sub verify (\%@) {
 	my ($options,@valid_options) = @_;
 	for (keys %$options) {
-		die "Invalid option $_\n" unless in ($_, @valid_options);
+		croak "Invalid option $_\n" unless in ($_, @valid_options);
 	}
 }
 
